# -*- coding: utf-8 -*-


# PyPlanets: Object-oriented refactoring of PyMeeus, a Python library implementing astronomical algorithms.
# Copyright (C) 2020  Martin Fünffinger
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU Lesser General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public License
# along with this program.  If not, see <https://www.gnu.org/licenses/>.


NUTATION_ARG_TABLE = [
    [0, 0, 0, 0, 1],
    [-2, 0, 0, 2, 2],
    [0, 0, 0, 2, 2],
    [0, 0, 0, 0, 2],
    [0, 1, 0, 0, 0],
    [0, 0, 1, 0, 0],
    [-2, 1, 0, 2, 2],
    [0, 0, 0, 2, 1],
    [0, 0, 1, 2, 2],
    [-2, -1, 0, 2, 2],
    [-2, 0, 1, 0, 0],
    [-2, 0, 0, 2, 1],
    [0, 0, -1, 2, 2],
    [2, 0, 0, 0, 0],
    [0, 0, 1, 0, 1],
    [2, 0, -1, 2, 2],
    [0, 0, -1, 0, 1],
    [0, 0, 1, 2, 1],
    [-2, 0, 2, 0, 0],
    [0, 0, -2, 2, 1],
    [2, 0, 0, 2, 2],
    [0, 0, 2, 2, 2],
    [0, 0, 2, 0, 0],
    [-2, 0, 1, 2, 2],
    [0, 0, 0, 2, 0],
    [-2, 0, 0, 2, 0],
    [0, 0, -1, 2, 1],
    [0, 2, 0, 0, 0],
    [2, 0, -1, 0, 1],
    [-2, 2, 0, 2, 2],
    [0, 1, 0, 0, 1],
    [-2, 0, 1, 0, 1],
    [0, -1, 0, 0, 1],
    [0, 0, 2, -2, 0],
    [2, 0, -1, 2, 1],
    [2, 0, 1, 2, 2],
    [0, 1, 0, 2, 2],
    [-2, 1, 1, 0, 0],
    [0, -1, 0, 2, 2],
    [2, 0, 0, 2, 1],
    [2, 0, 1, 0, 0],
    [-2, 0, 2, 2, 2],
    [-2, 0, 1, 2, 1],
    [2, 0, -2, 0, 1],
    [2, 0, 0, 0, 1],
    [0, -1, 1, 0, 0],
    [-2, -1, 0, 2, 1],
    [-2, 0, 0, 0, 1],
    [0, 0, 2, 2, 1],
    [-2, 0, 2, 0, 1],
    [-2, 1, 0, 2, 1],
    [0, 0, 1, -2, 0],
    [-1, 0, 1, 0, 0],
    [-2, 1, 0, 0, 0],
    [1, 0, 0, 0, 0],
    [0, 0, 1, 2, 0],
    [0, 0, -2, 2, 2],
    [-1, -1, 1, 0, 0],
    [0, 1, 1, 0, 0],
    [0, -1, 1, 2, 2],
    [2, -1, -1, 2, 2],
    [0, 0, 3, 2, 2],
    [2, -1, 0, 2, 2],
]
"""This table contains the periodic terms for the argument of the nutation. In
Meeus' book this is Table 22.A and can be found in pages 145-146."""

NUTATION_SINE_COEF_TABLE = [
    [-171996.0, -174.2],
    [-13187.0, -1.6],
    [-2274.0, -0.2],
    [2062.0, 0.2],
    [1426.0, -3.4],
    [712.0, 0.1],
    [-517.0, 1.2],
    [-386.0, -0.4],
    [-301.0, 0.0],
    [217.0, -0.5],
    [-158.0, 0.0],
    [129.0, 0.1],
    [123.0, 0.0],
    [63.0, 0.0],
    [63.0, 0.1],
    [-59.0, 0.0],
    [-58.0, -0.1],
    [-51.0, 0.0],
    [48.0, 0.0],
    [46.0, 0.0],
    [-38.0, 0.0],
    [-31.0, 0.0],
    [29.0, 0.0],
    [29.0, 0.0],
    [26.0, 0.0],
    [-22.0, 0.0],
    [21.0, 0.0],
    [17.0, -0.1],
    [16.0, 0.0],
    [-16.0, 0.1],
    [-15.0, 0.0],
    [-13.0, 0.0],
    [-12.0, 0.0],
    [11.0, 0.0],
    [-10.0, 0.0],
    [-8.0, 0.0],
    [7.0, 0.0],
    [-7.0, 0.0],
    [-7.0, 0.0],
    [-7.0, 0.0],
    [6.0, 0.0],
    [6.0, 0.0],
    [6.0, 0.0],
    [-6.0, 0.0],
    [-6.0, 0.0],
    [5.0, 0.0],
    [-5.0, 0.0],
    [-5.0, 0.0],
    [-5.0, 0.0],
    [4.0, 0.0],
    [4.0, 0.0],
    [4.0, 0.0],
    [-4.0, 0.0],
    [-4.0, 0.0],
    [-4.0, 0.0],
    [3.0, 0.0],
    [-3.0, 0.0],
    [-3.0, 0.0],
    [-3.0, 0.0],
    [-3.0, 0.0],
    [-3.0, 0.0],
    [-3.0, 0.0],
    [-3.0, 0.0],
]
"""This table contains the periodic terms for the coefficients of the sine of
the argument of the nutation, and they are used to compute Delta psi. Units are
in 0.0001''. In Meeus' book this is Table 22.A and can be found in pages
145-146."""

NUTATION_COSINE_COEF_TABLE = [
    [92025.0, 8.9],
    [5736.0, -3.1],
    [977.0, -0.5],
    [-895.0, 0.5],
    [54.0, -0.1],
    [-7.0, 0.0],
    [224.0, -0.6],
    [200.0, 0.0],
    [129.0, -0.1],
    [-95.0, 0.3],
    [0.0, 0.0],
    [-70.0, 0.0],
    [-53.0, 0.0],
    [0.0, 0.0],
    [-33.0, 0.0],
    [26.0, 0.0],
    [32.0, 0.0],
    [27.0, 0.0],
    [0.0, 0.0],
    [-24.0, 0.0],
    [16.0, 0.0],
    [13.0, 0.0],
    [0.0, 0.0],
    [-12.0, 0.0],
    [0.0, 0.0],
    [0.0, 0.0],
    [-10.0, 0.0],
    [0.0, 0.0],
    [-8.0, 0.0],
    [7.0, 0.0],
    [9.0, 0.0],
    [7.0, 0.0],
    [6.0, 0.0],
    [0.0, 0.0],
    [5.0, 0.0],
    [3.0, 0.0],
    [-3.0, 0.0],
    [0.0, 0.0],
    [3.0, 0.0],
    [3.0, 0.0],
    [0.0, 0.0],
    [-3.0, 0.0],
    [-3.0, 0.0],
    [3.0, 0.0],
    [3.0, 0.0],
    [0.0, 0.0],
    [3.0, 0.0],
    [3.0, 0.0],
    [3.0, 0.0],
]
"""This table contains the periodic terms for the coefficients of the cosine of
the argument of the nutation, and they are used to compute Delta epsilon. Units
are in 0.0001''. In Meeus' book this is Table 22.A and can be found in pages
145-146."""
