# -*- coding: utf-8 -*-


# PyPlanets: Object-oriented refactoring of PyMeeus, a Python library implementing astronomical algorithms.
# Copyright (C) 2020  Martin Fünffinger
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU Lesser General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public License
# along with this program.  If not, see <https://www.gnu.org/licenses/>.


PLUTO_ARGUMENT = [
    (0.0, 0.0, 1.0),
    (0.0, 0.0, 2.0),
    (0.0, 0.0, 3.0),
    (0.0, 0.0, 4.0),
    (0.0, 0.0, 5.0),
    (0.0, 0.0, 6.0),
    (0.0, 1.0, -1.0),
    (0.0, 1.0, 0.0),
    (0.0, 1.0, 1.0),
    (0.0, 1.0, 2.0),
    (0.0, 1.0, 3.0),
    (0.0, 2.0, -2.0),
    (0.0, 2.0, -1.0),
    (0.0, 2.0, 0.0),
    (1.0, -1.0, 0.0),
    (1.0, -1.0, 1.0),
    (1.0, 0.0, -3.0),
    (1.0, 0.0, -2.0),
    (1.0, 0.0, -1.0),
    (1.0, 0.0, 0.0),
    (1.0, 0.0, 1.0),
    (1.0, 0.0, 2.0),
    (1.0, 0.0, 3.0),
    (1.0, 0.0, 4.0),
    (1.0, 1.0, -3.0),
    (1.0, 1.0, -2.0),
    (1.0, 1.0, -1.0),
    (1.0, 1.0, 0.0),
    (1.0, 1.0, 1.0),
    (1.0, 1.0, 3.0),
    (2.0, 0.0, -6.0),
    (2.0, 0.0, -5.0),
    (2.0, 0.0, -4.0),
    (2.0, 0.0, -3.0),
    (2.0, 0.0, -2.0),
    (2.0, 0.0, -1.0),
    (2.0, 0.0, 0.0),
    (2.0, 0.0, 1.0),
    (2.0, 0.0, 2.0),
    (2.0, 0.0, 3.0),
    (3.0, 0.0, -2.0),
    (3.0, 0.0, -1.0),
    (3.0, 0.0, 0.0)
]
"""This table contains Pluto's argument coefficients according to Table 37.A in
Meeus' book, page 265."""


PLUTO_LONGITUDE = [
    (-19799805.0, 19850055.0),
    (897144.0, -4954829.0),
    (611149.0, 1211027.0),
    (-341243.0, -189585.0),
    (129287.0, -34992.0),
    (-38164.0, 30893.0),
    (20442.0, -9987.0),
    (-4063.0, -5071.0),
    (-6016.0, -3336.0),
    (-3956.0, 3039.0),
    (-667.0, 3572.0),
    (1276.0, 501.0),
    (1152.0, -917.0),
    (630.0, -1277.0),
    (2571.0, -459.0),
    (899.0, -1449.0),
    (-1016.0, 1043.0),
    (-2343.0, -1012.0),
    (7042.0, 788.0),
    (1199.0, -338.0),
    (418.0, -67.0),
    (120.0, -274.0),
    (-60.0, -159.0),
    (-82.0, -29.0),
    (-36.0, -29.0),
    (-40.0, 7.0),
    (-14.0, 22.0),
    (4.0, 13.0),
    (5.0, 2.0),
    (-1.0, 0.0),
    (2.0, 0.0),
    (-4.0, 5.0),
    (4.0, -7.0),
    (14.0, 24.0),
    (-49.0, -34.0),
    (163.0, -48.0),
    (9.0, -24.0),
    (-4.0, 1.0),
    (-3.0, 1.0),
    (1.0, 3.0),
    (-3.0, -1.0),
    (5.0, -3.0),
    (0.0, 0.0)
]
"""This table contains the periodic terms to compute Pluto's heliocentric
longitude according to Table 37.A in Meeus' book, page 265"""


PLUTO_LATITUDE = [
    (-5452852.0, -14974862),
    (3527812.0, 1672790.0),
    (-1050748.0, 327647.0),
    (178690.0, -292153.0),
    (18650.0, 100340.0),
    (-30697.0, -25823.0),
    (4878.0, 11248.0),
    (226.0, -64.0),
    (2030.0, -836.0),
    (69.0, -604.0),
    (-247.0, -567.0),
    (-57.0, 1.0),
    (-122.0, 175.0),
    (-49.0, -164.0),
    (-197.0, 199.0),
    (-25.0, 217.0),
    (589.0, -248.0),
    (-269.0, 711.0),
    (185.0, 193.0),
    (315.0, 807.0),
    (-130.0, -43.0),
    (5.0, 3.0),
    (2.0, 17.0),
    (2.0, 5.0),
    (2.0, 3.0),
    (3.0, 1.0),
    (2.0, -1.0),
    (1.0, -1.0),
    (0.0, -1.0),
    (0.0, 0.0),
    (0.0, -2.0),
    (2.0, 2.0),
    (-7.0, 0.0),
    (10.0, -8.0),
    (-3.0, 20.0),
    (6.0, 5.0),
    (14.0, 17.0),
    (-2.0, 0.0),
    (0.0, 0.0),
    (0.0, 0.0),
    (0.0, 1.0),
    (0.0, 0.0),
    (1.0, 0.0)
]
"""This table contains the periodic terms to compute Pluto's heliocentric
latitude according to Table 37.A in Meeus' book, page 265"""


PLUTO_RADIUS_VECTOR = [
    (66865439.0, 68951812.0),
    (-11827535.0, -332538.0),
    (1593179.0, -1438890.0),
    (-18444.0, 483220.0),
    (-65977.0, -85431.0),
    (31174.0, -6032.0),
    (-5794.0, 22161.0),
    (4601.0, 4032.0),
    (-1729.0, 234.0),
    (-415.0, 702.0),
    (239.0, 723.0),
    (67.0, -67.0),
    (1034.0, -451.0),
    (-129.0, 504.0),
    (480.0, -231.0),
    (2.0, -441.0),
    (-3359.0, 265.0),
    (7856.0, -7832.0),
    (36.0, 45763.0),
    (8663.0, 8547.0),
    (-809.0, -769.0),
    (263.0, -144.0),
    (-126.0, 32.0),
    (-35.0, -16.0),
    (-19.0, -4.0),
    (-15.0, 8.0),
    (-4.0, 12.0),
    (5.0, 6.0),
    (3.0, 1.0),
    (6.0, -2.0),
    (2.0, 2.0),
    (-2.0, -2.0),
    (14.0, 13.0),
    (-63.0, 13.0),
    (136.0, -236.0),
    (273.0, 1065.0),
    (251.0, 149.0),
    (-25.0, -9.0),
    (9.0, -2.0),
    (-8.0, 7.0),
    (2.0, -10.0),
    (19.0, 35.0),
    (10.0, 3.0)
]
"""This table contains the periodic terms to compute Pluto's heliocentric
radius vector according to Table 37.A in Meeus' book, page 265"""
